.. :changelog:

History
-------

0.3.0 (24-03-2020)
---------------------

* updated CI and docker to python 3.6
* changed dockerfile from using CMD to ENTRYPOINT


0.2.6 (21-03-2020)
---------------------

* updated transip lib

0.1.4 (18-01-2019)
---------------------

* Added docker image + instructions

0.1.2 (12-11-2018)
---------------------

* Updated the API for transip to current version

0.1 (14-07-2017)
---------------------

* First release on https://pypi.python.org/pypi/certbot-dns-transip
